Subject: Re: bug#32787: Typos in Shepperd

From: Rafael Fontenelle <[email-masked]>
Date: Thu, 20 Sep 2018 20:32:36 -0300

Hi there, Carlo

Em qui, 20 de set de 2018 às 18:31, Carlo Zancanaro
<[email-masked]> escreveu:
>
> Could you send the patch through as formatted by "git
> format-patch" and with a commit message in the "ChangeLog"[1]
> format? It's probably easiest to just copy the style of commit
> messages in the repository.

No problem. See attached patch. Please check if the commit message is
as expected.

Rafael Fontenelle
From 2e8734f7e7a6560e89d3f06038d405e2655b6a47 Mon Sep 17 00:00:00 2001
From: Rafael Fontenelle <[email-masked]>
Date: Thu, 20 Sep 2018 20:23:47 -0300
Subject: [PATCH] Fix typographic erros.

This solves some misspelled words throughout the code.

 * configure.ac: procude->produce
 * doc/shepherd.texi: several typo fixes
 * modules/shepherd/args.scm: ambigous->ambiguous
 * modules/shepherd/service.scm: childs->children
---
 configure.ac                 |  2 +-
 doc/shepherd.texi            | 18 +++++++++---------
 modules/shepherd/args.scm    |  6 +++---
 modules/shepherd/service.scm |  6 +++---
 4 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/configure.ac b/configure.ac
index 0039093..a270361 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,4 +1,4 @@
-dnl Process this file with autoconf to procude a configure script.
+dnl Process this file with autoconf to produce a configure script.
 
 AC_PREREQ(2.69)
 
diff --git a/doc/shepherd.texi b/doc/shepherd.texi
index f54fa6f..73f2fc3 100644
--- a/doc/shepherd.texi
+++ b/doc/shepherd.texi
@@ -651,7 +651,7 @@ therefore it is desirable to specify a different one usually.
 
 @item
 @vindex stop (slot of <service>)
-@cindex Stoping a service
+@cindex Stopping a service
 @cindex Service destructor
 @code{stop} is, similar to @code{start}, a slot containing a
 procedure.  But in this case, it gets the current value of the
@@ -729,7 +729,7 @@ It tries quite hard to do this: When a service that provides a
 required symbol can not be started, it will look for another service
 that also provides this symbol, until starting one such service
 succeeds.  There is some room for theoretical improvement here, of
-course, but in pratice the current strategy already works very well.
+course, but in practice the current strategy already works very well.
 This method returns the new value of the @code{running} slot
 @ref{Slots of services}, which is @code{#f} if the service could not
 be started.
@@ -1063,8 +1063,8 @@ message and throw an @code{assertion-failed} exception.
 @end deffn
 
 @deffn {procedure} caught-error key args
-Tell the Shepherd that a @var{key} error with @var{args} has occured.  This is
-the simplest way to cause caught error result in uniformly formated
+Tell the Shepherd that a @var{key} error with @var{args} has occurred.  This is
+the simplest way to cause caught error result in uniformly formatted
 warning messages.  The current implementation is not very good,
 though.
 @end deffn
@@ -1245,11 +1245,11 @@ sometimes useful, but often one also wants to operate on single
 services.  System V Init makes this hard: While you can start and stop
 a service, @code{init} will not know about it, and use the runlevel
 configuration as its source of information, opening the door for
-inconsistencies (which fortunatly are not a practical problem
+inconsistencies (which fortunately are not a practical problem
 usually).  In the Shepherd, this was avoided by having a central entity that is
 responsible for starting and stopping the services, which therefore
 knows which services are actually started (if not completely
-inproperly used, but that is a requirement which is impossible to
+improperly used, but that is a requirement which is impossible to
 avoid anyway).  While runlevels are not implemented yet, it is clear
 that they will sit on top of the service concept, i.e. runlevels will
 merely be an optional extension that the service concept does not rely
@@ -1258,7 +1258,7 @@ become necessary.
 
 The consequence of having a daemon running that controls the services
 is that we need another program as user interface which communicates
-with the daemon.  Fortunatly, this makes the commands necessary for
+with the daemon.  Fortunately, this makes the commands necessary for
 controlling services pretty short and intuitive, and gives the
 additional bonus of adding some more flexibility.  For example, it is
 easiely possible to grant password-protected control over certain
@@ -1269,7 +1269,7 @@ above) is that it should always know exactly what is happening,
 i.e. which services are started and stopped.  The alternative would
 have been to not use a daemon, but to save the state on the file
 system, again opening the door for inconsistencies of all sorts.
-Also, we would have to use a seperate program for respawning a service
+Also, we would have to use a separate program for respawning a service
 (which just starts the services, waits until it terminates and then
 starts it again).  Killing the program that does the respawning (but
 not the service that is supposed to be respawned) would cause horrible
@@ -1544,7 +1544,7 @@ we find which combination works?  I found only one way yet: Kind of a
 brute force attack: Try combinations until we find one that works.
 
 This alone would be too slow.  With 20 services we would have 2^20
-possible combinations, that is a bit more than a million.  Fortunatly,
+possible combinations, that is a bit more than a million.  Fortunately,
 we can optimize this.  First I thought we could remove all services
 from the list that do not provide any symbol we need, but that is
 obviously a stupid idea, as we might need them for dependencies, in
diff --git a/modules/shepherd/service.scm b/modules/shepherd/service.scm
index 8df1329..6cc52ba 100644
--- a/modules/shepherd/service.scm
+++ b/modules/shepherd/service.scm
@@ -1328,7 +1328,7 @@ removing them if needed."
         (deregister-service service-name)))
      (reload
       "Unload all services, then load from FILE-NAME into shepherd.  This
-is potentialy dangerous.  You have been warned."
+is potentially dangerous.  You have been warned."
       (lambda (running file-name)
         (and (deregister-service "all") ; unload all services
              (load-config file-name)))) ; reload from FILE-NAME
@@ -1336,8 +1336,8 @@ is potentialy dangerous.  You have been warned."
      (daemonize
       "Go into the background.  Be careful, this means that a new
 process will be created, so shepherd will not get SIGCHLD signals anymore
-if previously spawned childs terminate.  Therefore, this action should
-usually only be used (if at all) *before* childs get spawned for which
+if previously spawned children terminate.  Therefore, this action should
+usually only be used (if at all) *before* children get spawned for which
 we want to receive these signals."
       (lambda (running)
         (case (getpid)
diff --git a/modules/shepherd/args.scm b/modules/shepherd/args.scm
index 3f00d11..604768f 100644
--- a/modules/shepherd/args.scm
+++ b/modules/shepherd/args.scm
@@ -27,7 +27,7 @@
 
 ;; This does mostly the same as getopt-long, except for that it is
 ;; able to recognize abbreviations for long options, as long as they
 ;; are not ambigous.  Additionally, output is done in a way that makes
 ;; localization possible.
 
 (define-class <option> ()
@@ -102,7 +102,7 @@
   ;; If this returns `#f', it means no option that can be abbreviated
   ;; as NAME (or has exactly this name) was found.  If the return
   ;; value is an option, it is exactly that or an abbreviation for it.
   ;; `#t' means that it is ambigous.
   (define (find-long-option name)
     (call/ec (lambda (return)
 	       (let ((abbrev-for #f))
@@ -251,7 +251,7 @@ General help using GNU software: <http://www.gnu.org/gethelp/>~%")
 		      (begin
 			(local-output
 			 (if target-option
-			     (l10n "Option `--~a' is ambigous.")
+			     (l10n "Option `--~a' is ambiguous.")
 			   (l10n "Unknown option: `--~a'."))
 			 name)
 			(local-output (l10n "Try `--help'."))
@@ -27,7 +27,7 @@
 ;; This does mostly the same as getopt-long, except for that it is
 ;; able to recognize abbreviations for long options, as long as they
-;; are not ambigous.  Additionally, output is done in a way that makes
+;; are not ambiguous.  Additionally, output is done in a way that makes
 ;; localization possible.
 
@@ -102,7 +102,7 @@
   ;; as NAME (or has exactly this name) was found.  If the return
   ;; value is an option, it is exactly that or an abbreviation for it.
-  ;; `#t' means that it is ambigous.
+  ;; `#t' means that it is ambiguous.
   (define (find-long-option name)
     (call/ec (lambda (return)
-- 
2.19.0